@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,13 +16,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-persist.c,v 1.24 2005/02/26 22:01:47 chpe Exp $
+ *  $Id: ephy-embed-persist.c 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "config.h"
 
 #include "ephy-embed-persist.h"
 #include "mozilla-embed-persist.h"
+#include "ephy-embed-type-builtins.h"
 #include "ephy-debug.h"
 
 #include <gtk/gtkmain.h>
@@ -51,7 +52,7 @@ struct _EphyEmbedPersistPrivate
 	char *fc_title;
 	char *persist_key;
 	EphyEmbed *embed;
-	long max_size;
+	gint64 max_size;
 	EphyEmbedPersistFlags flags;
 	GtkWindow *fc_parent;
 	guint32 user_time;
@@ -69,7 +70,7 @@ ephy_embed_persist_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyEmbedPersistClass),
 			NULL, /* base_init */
@@ -201,7 +202,7 @@ ephy_embed_persist_set_flags (EphyEmbedPersist *persist,
  **/
 void
 ephy_embed_persist_set_max_size (EphyEmbedPersist *persist,
-				 long value)
+				 gint64 value)
 {
 	g_return_if_fail (EPHY_IS_EMBED_PERSIST (persist));
 
@@ -351,7 +352,7 @@ ephy_embed_persist_get_flags (EphyEmbedPersist *persist)
  *
  * Return value: the maximum size of @persist's requested download, in bytes
  **/
-long
+gint64
 ephy_embed_persist_get_max_size (EphyEmbedPersist *persist)
 {
 	g_return_val_if_fail (EPHY_IS_EMBED_PERSIST (persist), 0);
@@ -432,10 +433,10 @@ ephy_embed_persist_set_property (GObject *object,
 			ephy_embed_persist_set_fc_parent (persist, g_value_get_object (value));
 			break;
 		case PROP_FLAGS:
-			ephy_embed_persist_set_flags (persist, g_value_get_int (value));
+			ephy_embed_persist_set_flags (persist, g_value_get_flags (value));
 			break;
 		case PROP_MAX_SIZE:
-			ephy_embed_persist_set_max_size (persist, g_value_get_long (value));
+			ephy_embed_persist_set_max_size (persist, g_value_get_int64 (value));
 			break;
 		case PROP_PERSISTKEY:
 			ephy_embed_persist_set_persist_key (persist, g_value_get_string (value));
@@ -472,10 +473,10 @@ ephy_embed_persist_get_property (GObject *object,
 			g_value_set_object (value, ephy_embed_persist_get_fc_parent (persist));
 			break;
 		case PROP_FLAGS:
-			g_value_set_int (value, ephy_embed_persist_get_flags (persist));
+			g_value_set_flags (value, ephy_embed_persist_get_flags (persist));
 			break;
 		case PROP_MAX_SIZE:
-			g_value_set_long (value, ephy_embed_persist_get_max_size (persist));
+			g_value_set_int64 (value, ephy_embed_persist_get_max_size (persist));
 			break;
 		case PROP_PERSISTKEY:
 			g_value_set_string (value, ephy_embed_persist_get_persist_key (persist));
@@ -572,7 +573,7 @@ ephy_embed_persist_class_init (EphyEmbedPersistClass *klass)
 							      "Destination",
 							      "Destination file path",
 							      NULL,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_EMBED,
@@ -580,7 +581,7 @@ ephy_embed_persist_class_init (EphyEmbedPersistClass *klass)
 							      "Embed",
 							      "The embed containing the document",
 							      G_TYPE_OBJECT,
-							      G_PARAM_READWRITE |
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 							      G_PARAM_CONSTRUCT_ONLY));
 
 	g_object_class_install_property (object_class,
@@ -589,7 +590,7 @@ ephy_embed_persist_class_init (EphyEmbedPersistClass *klass)
 							       "Filechooser title",
 							       "Title to use if showing filechooser",
 							       NULL,
-							       G_PARAM_READWRITE));
+							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_FILECHOOSER_PARENT,
@@ -597,27 +598,26 @@ ephy_embed_persist_class_init (EphyEmbedPersistClass *klass)
 							      "Filechooser parent",
 							      "The parent window for the filechooser",
 							      GTK_TYPE_WINDOW,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_FLAGS,
-					 g_param_spec_int    ("flags",
+					 g_param_spec_flags  ("flags",
 							      "Flags",
 							      "Flags",
+							      EPHY_TYPE_EMBED_PERSIST_FLAGS,
 							      0,
-							      G_MAXINT,
-							      0,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_MAX_SIZE,
-					 g_param_spec_long   ("max_size",
+					 g_param_spec_int64  ("max-size",
 							      "Maxsize",
 							      "Maximum size of the file",
-							      0,
-							      G_MAXLONG,
-							      0,
-							      G_PARAM_READWRITE));
+							      -1,
+							      G_MAXINT64,
+							      -1,
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_PERSISTKEY,
@@ -625,7 +625,7 @@ ephy_embed_persist_class_init (EphyEmbedPersistClass *klass)
 							       "persist key",
 							       "Path persistence gconf key",
 							       NULL,
-							       G_PARAM_READWRITE));
+							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_SOURCE,
@@ -633,7 +633,7 @@ ephy_embed_persist_class_init (EphyEmbedPersistClass *klass)
 							       "Source",
 							       "Url of the document to save",
 							       NULL,
-							       G_PARAM_READWRITE));
+							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_USER_TIME,
@@ -643,7 +643,7 @@ ephy_embed_persist_class_init (EphyEmbedPersistClass *klass)
 							      0,
 							      G_MAXUINT,
 							      0,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_type_class_add_private (object_class, sizeof(EphyEmbedPersistPrivate));
 }
