@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,14 +15,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-shell.h,v 1.20 2006/02/02 17:27:40 chpe Exp $
+ *  $Id: ephy-embed-shell.h 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #ifndef EPHY_EMBED_SHELL_H
 #define EPHY_EMBED_SHELL_H
 
-#include <glib-object.h>
 #include <glib.h>
+#include <glib-object.h>
+#include <gtk/gtkpagesetup.h>
+#include <gtk/gtkprintsettings.h>
 
 G_BEGIN_DECLS
 
@@ -77,6 +79,16 @@ GObject        	  *ephy_embed_shell_get_adblock_manager	(EphyEmbedShell *shell);
 
 void		   ephy_embed_shell_prepare_close	(EphyEmbedShell *shell);
 
+void		   ephy_embed_shell_set_page_setup	(EphyEmbedShell *shell,
+							 GtkPageSetup *page_setup);
+		
+GtkPageSetup	  *ephy_embed_shell_get_page_setup	(EphyEmbedShell *shell);
+
+void		   ephy_embed_shell_set_print_settings	(EphyEmbedShell *shell,
+							 GtkPrintSettings *settings);
+		
+GtkPrintSettings  *ephy_embed_shell_get_print_settings	(EphyEmbedShell *shell);
+
 G_END_DECLS
 
 #endif /* !EPHY_EMBED_SHELL_H */
