@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2002, 2003 Marco Pesenti Gritti
+ *  Copyright © 2002, 2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history.c,v 1.64 2006/01/22 10:56:32 crispin Exp $
+ *  $Id: ephy-history.c 6785 2007-01-03 08:17:59Z diegoe $
  */
 
 #include "config.h"
@@ -43,6 +43,9 @@
 /* if you change this remember to change also the user interface description */
 #define HISTORY_PAGE_OBSOLETE_DAYS 10
 
+/* the number of seconds in a day */
+#define SECS_PER_DAY (60*60*24)
+
 #define EPHY_HISTORY_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_HISTORY, EphyHistoryPrivate))
 
 struct _EphyHistoryPrivate
@@ -98,7 +101,7 @@ ephy_history_get_type (void)
 
         if (G_UNLIKELY (type == 0))
         {
-                static const GTypeInfo our_info =
+                const GTypeInfo our_info =
                 {
                         sizeof (EphyHistoryClass),
                         NULL, /* base_init */
@@ -238,23 +241,13 @@ ephy_history_class_init (EphyHistoryClass *klass)
 }
 
 static gboolean
-page_is_obsolete (EphyNode *node, GDate *now)
+page_is_obsolete (EphyNode *node, time_t now)
 {
 	int last_visit;
-	GDate date;
 
 	last_visit = ephy_node_get_property_int
 		(node, EPHY_NODE_PAGE_PROP_LAST_VISIT);
-
-        g_date_clear (&date, 1);
-#if GLIB_CHECK_VERSION (2,9,0)
-        g_date_set_time_t (&date, last_visit);
-#else
-        g_date_set_time (&date, last_visit);
-#endif
-
-	return (g_date_days_between (&date, now) >=
-		HISTORY_PAGE_OBSOLETE_DAYS);
+	return now - last_visit >= HISTORY_PAGE_OBSOLETE_DAYS*SECS_PER_DAY;
 }
 
 static void
@@ -262,16 +255,9 @@ remove_obsolete_pages (EphyHistory *eb)
 {
 	GPtrArray *children;
 	int i;
-	GTime now;
-	GDate current_date;
+	time_t now;
 
 	now = time (NULL);
-        g_date_clear (&current_date, 1);
-#if GLIB_CHECK_VERSION (2,9,0)
-        g_date_set_time_t (&current_date, time (NULL));
-#else
-        g_date_set_time (&current_date, time (NULL));
-#endif
 
 	children = ephy_node_get_children (eb->priv->pages);
 	for (i = (int) children->len - 1; i >= 0; i--)
@@ -280,7 +266,7 @@ remove_obsolete_pages (EphyHistory *eb)
 
 		kid = g_ptr_array_index (children, i);
 
-		if (page_is_obsolete (kid, &current_date))
+		if (page_is_obsolete (kid, now))
 		{
 			ephy_node_unref (kid);
 		}
