@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Robert Marcano
- *  Copyright (C) 2005 Crispin Flowerday
+ *  Copyright © 2003 Robert Marcano
+ *  Copyright © 2005 Crispin Flowerday
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-x509-cert.c,v 1.1 2005/12/11 14:40:15 chpe Exp $
+ * $Id: ephy-x509-cert.c 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include <config.h>
@@ -30,7 +30,7 @@ ephy_x509_cert_get_type (void)
 
 	if (ephy_x509_cert_type == 0)
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyX509CertIface),
 			NULL,
