@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyAboutModule.cpp,v 1.15.2.1 2006/09/13 11:48:34 chpe Exp $
+ *  $Id: EphyAboutModule.cpp 6802 2007-01-08 23:16:02Z diegoe $
  */
 
 #include "mozilla-config.h"
@@ -533,10 +533,10 @@ EphyAboutModule::CreateRecoverPage(nsIURI *aRecoverURI,
 	rv = NS_NewURI(getter_AddRefs (uri), url, charset.get());
 	NS_ENSURE_SUCCESS (rv, rv);
 
-	char *secondary = g_strdup_printf
+	char *secondary = g_markup_printf_escaped
 		(_("The page “%s” in this tab was not fully loaded yet when "
 		   "the web browser crashed; it could have caused the crash."),
-		 rawurl.get());
+		 url.get());
 
 	nsCOMPtr<nsIChannel> channel;
 	rv = WritePage (aRecoverURI, uri, uri, rawurl, title.get(),
