@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005 Christian Persch
+ *  Copyright © 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,59 +15,58 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyFind.cpp,v 1.4 2005/11/03 12:37:14 chpe Exp $
+ *  $Id: EphyFind.cpp 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
-#include "EphyFind.h"
-
-#include "ephy-debug.h"
-
-#undef MOZILLA_INTERNAL_API
-#include <nsEmbedString.h>
-#define MOZILLA_INTERNAL_API 1
-
-#include <gtkmozembed.h>
-#include <gtkmozembed_internal.h>
-#include <nsCOMPtr.h>
-#include <nsIServiceManager.h>
-#include <nsIInterfaceRequestorUtils.h>
-#include <nsIDOMWindow.h>
-#include <nsIWebBrowser.h>
-#include <nsIWebBrowserFocus.h>
-#include <nsIDOMNode.h>
-#include <nsIDOMElement.h>
-#include <nsIDOMDocument.h>
-#include <nsIDOMDocumentView.h>
-#include <nsIDOMAbstractView.h>
-#include <nsIDOMDocumentEvent.h>
-#include <nsIDOMEvent.h>
-#include <nsIDOMKeyEvent.h>
-#include <nsIDOMEventTarget.h>
-#include <nsIDOMHTMLAnchorElement.h>
-
-#ifdef HAVE_TYPEAHEADFIND
-#include <nsIDocShell.h>
-#include <nsITypeAheadFind.h>
-#else
-#include <nsIWebBrowserFind.h>
-#include <nsMemory.h>
-#endif
-
 #include <glib.h>
 
-#ifdef HAVE_TYPEAHEADFIND
+#include <nsStringAPI.h>
+
+#include <gtkmozembed.h>
+#include <gtkmozembed_internal.h>
+#include <nsComponentManagerUtils.h>
+#include <nsCOMPtr.h>
+#include <nsIDocShell.h>
+#include <nsIDOMAbstractView.h>
+#include <nsIDOMDocumentEvent.h>
+#include <nsIDOMDocument.h>
+#include <nsIDOMDocumentView.h>
+#include <nsIDOMElement.h>
+#include <nsIDOMEvent.h>
+#include <nsIDOMEventTarget.h>
+#include <nsIDOMHTMLAnchorElement.h>
+#include <nsIDOMKeyEvent.h>
+#include <nsIDOMNode.h>
+#include <nsIDOMWindow.h>
+#include <nsIInterfaceRequestorUtils.h>
+#include <nsISelectionController.h>
+#include <nsISelectionDisplay.h>
+#include <nsITypeAheadFind.h>
+#include <nsIWebBrowserFocus.h>
+#include <nsIWebBrowser.h>
+#include <nsServiceManagerUtils.h>
+
+#ifndef HAVE_GECKO_1_9
+#include <nsIDocShellTreeItem.h>
+#include <nsISimpleEnumerator.h>
+#endif
+
+#include "ephy-debug.h"
+
+#include "EphyFind.h"
+
 #define NS_TYPEAHEADFIND_CONTRACTID "@mozilla.org/typeaheadfind;1"
-#endif /* HAVE_TYPEAHEADFIND */
 
 static const PRUnichar kKeyEvents[] = { 'K', 'e', 'y', 'E', 'v', 'e', 'n', 't', 's', '\0' };
 static const PRUnichar kKeyPress[] = { 'k', 'e', 'y', 'p', 'r', 'e', 's', 's', '\0' };
 
 EphyFind::EphyFind ()
 : mCurrentEmbed(nsnull)
+, mAttention(PR_FALSE)
+, mHasFocus(PR_FALSE) /* FIXME!! */
 {
   LOG ("EphyFind ctor [%p]", this);
 }
@@ -83,6 +82,8 @@ EphyFind::SetEmbed (EphyEmbed *aEmbed)
   nsresult rv = NS_OK;
   if (aEmbed == mCurrentEmbed) return rv;
 
+  SetSelectionAttention (PR_FALSE);
+
   mCurrentEmbed = nsnull;
   mWebBrowser = nsnull;
 
@@ -91,7 +92,6 @@ EphyFind::SetEmbed (EphyEmbed *aEmbed)
 				   getter_AddRefs (mWebBrowser));
   NS_ENSURE_TRUE (mWebBrowser, rv);
 
-#ifdef HAVE_TYPEAHEADFIND
   nsCOMPtr<nsIDocShell> docShell (do_GetInterface (mWebBrowser, &rv));
   NS_ENSURE_SUCCESS (rv, rv);
 
@@ -100,27 +100,15 @@ EphyFind::SetEmbed (EphyEmbed *aEmbed)
     NS_ENSURE_SUCCESS (rv, rv);
 
     rv = mFinder->Init (docShell);
+#ifdef HAVE_GECKO_1_9
+//    mFinder->SetSelectionModeAndRepaint (nsISelectionController::SELECTION_ON);
+#else
     mFinder->SetFocusLinks (PR_TRUE);
+#endif
   } else {
     rv = mFinder->SetDocShell (docShell);
   }
   NS_ENSURE_SUCCESS (rv, rv);
-#else
-  PRUnichar *string = nsnull;
-  if (mFinder) {
-    mFinder->GetSearchString (&string);
-  }
-
-  mFinder = do_GetInterface (mWebBrowser, &rv);
-  NS_ENSURE_SUCCESS (rv, rv);
-
-  mFinder->SetWrapFind (PR_TRUE);
-
-  if (string) {
-    mFinder->SetSearchString (string);
-    nsMemory::Free (string);    
-  }
-#endif /* HAVE_TYPEAHEADFIND */
 
   mCurrentEmbed = aEmbed;
 
@@ -133,18 +121,57 @@ EphyFind::SetFindProperties (const char *aSearchString,
 {
   if (!mFinder) return;
 
-#ifdef HAVE_TYPEAHEADFIND
   mFinder->SetCaseSensitive (aCaseSensitive);
   /* search string is set on ::Find */
-#else 
-  mFinder->SetMatchCase (aCaseSensitive);
+}
+
+void
+EphyFind::SetSelectionAttention (PRBool aAttention)
+{
+  if (aAttention == mAttention) return;
+
+  mAttention = aAttention;
+
+  PRInt16 display;
+  if (aAttention) {
+    display = nsISelectionController::SELECTION_ATTENTION;
+  } else {
+    display = nsISelectionController::SELECTION_ON;
+  }
+
+#ifdef HAVE_GECKO_1_9
+  if (mFinder) {
+    mFinder->SetSelectionModeAndRepaint (display);
+  }
+#else
+  nsresult rv;
+  nsCOMPtr<nsIDocShell> shell (do_GetInterface (mWebBrowser, &rv));
+  /* It's okay for this to fail, if the tab is closing, or if
+   * we weren't attached to any tab yet
+   */
+  if (NS_FAILED (rv) || !shell) return;
+
+  nsCOMPtr<nsISimpleEnumerator> enumerator;
+  rv = shell->GetDocShellEnumerator (nsIDocShellTreeItem::typeContent,
+				     nsIDocShell::ENUMERATE_FORWARDS,
+				     getter_AddRefs (enumerator));
+  NS_ENSURE_SUCCESS (rv, );
+
+  PRBool hasMore = PR_FALSE;
+  while (NS_SUCCEEDED (enumerator->HasMoreElements (&hasMore)) && hasMore) {
+    nsCOMPtr<nsISupports> element;
+    enumerator->GetNext (getter_AddRefs (element));
+    if (!element) continue;
+	 
+    nsCOMPtr<nsISelectionDisplay> sd (do_GetInterface (element));
+    if (!sd) continue;
   
-  nsEmbedString uSearchString;
-  NS_CStringToUTF16 (nsEmbedCString (aSearchString ? aSearchString : ""),
-		     NS_CSTRING_ENCODING_UTF8, uSearchString);
-  
-  mFinder->SetSearchString (uSearchString.get ());
-#endif /* TYPEAHEADFIND */
+    nsCOMPtr<nsISelectionController> controller (do_QueryInterface (sd));
+    if (!controller) continue;
+
+    controller->SetDisplaySelection (display);
+  }
+#endif /* HAVE_GECKO_1_9 */
 }
 
 EphyEmbedFindResult
@@ -153,27 +180,21 @@ EphyFind::Find (const char *aSearchString,
 {
   if (!mFinder) return EPHY_EMBED_FIND_NOTFOUND;
 
-  nsEmbedString uSearchString;
-  NS_CStringToUTF16 (nsEmbedCString (aSearchString ? aSearchString : ""),
+  nsString uSearchString;
+  NS_CStringToUTF16 (nsCString (aSearchString ? aSearchString : ""),
   		     NS_CSTRING_ENCODING_UTF8, uSearchString);
 
-#ifdef HAVE_TYPEAHEADFIND
+  SetSelectionAttention (PR_TRUE);
+
   nsresult rv;
   PRUint16 found = nsITypeAheadFind::FIND_NOTFOUND;
+#ifdef HAVE_GECKO_1_9
+  rv = mFinder->Find (uSearchString, aLinksOnly, mHasFocus, &found);
+#else
   rv = mFinder->Find (uSearchString, aLinksOnly, &found);
+#endif
 
   return (EphyEmbedFindResult) found;
-#else
-  mFinder->SetSearchString (uSearchString.get ());
-  mFinder->SetFindBackwards (PR_FALSE);
-
-  nsresult rv;
-  PRBool didFind = PR_FALSE;
-  rv = mFinder->FindNext (&didFind);
-        
-  return NS_SUCCEEDED (rv) && didFind ? EPHY_EMBED_FIND_FOUND :
-		  			EPHY_EMBED_FIND_NOTFOUND;
-#endif /* HAVE_TYPEAHEADFIND */
 }
 
 EphyEmbedFindResult
@@ -181,26 +202,21 @@ EphyFind::FindAgain (PRBool aForward)
 {
   if (!mFinder) return EPHY_EMBED_FIND_NOTFOUND;
 
-#ifdef HAVE_TYPEAHEADFIND
+  SetSelectionAttention (PR_TRUE);
+
   nsresult rv;
   PRUint16 found = nsITypeAheadFind::FIND_NOTFOUND;
+#ifdef HAVE_GECKO_1_9
+  rv = mFinder->FindAgain (aForward, mHasFocus, &found);
+#else
   if (aForward) {
     rv = mFinder->FindNext (&found);
   } else {
     rv = mFinder->FindPrevious (&found);
   }
+#endif
 
   return (EphyEmbedFindResult) found;
-#else
-  mFinder->SetFindBackwards (!aForward);
-        
-  nsresult rv;
-  PRBool didFind = PR_FALSE;
-  rv = mFinder->FindNext (&didFind);
-
-  return NS_SUCCEEDED (rv) && didFind ? EPHY_EMBED_FIND_FOUND :
-		  EPHY_EMBED_FIND_NOTFOUND;
-#endif /* HAVE_TYPEAHEADFIND */
 }
 
 PRBool
@@ -208,20 +224,8 @@ EphyFind::ActivateLink (GdkModifierType aMask)
 {
 	nsresult rv;
 	nsCOMPtr<nsIDOMElement> link;
-#if defined(HAVE_TYPEAHEADFIND) && defined(HAVE_GECKO_1_8)
 	rv = mFinder->GetFoundLink (getter_AddRefs (link));
-	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && link, FALSE);
-#else
-	nsCOMPtr<nsIWebBrowserFocus> focus (do_QueryInterface (mWebBrowser));
-	NS_ENSURE_TRUE (focus, FALSE);
-
-	rv = focus->GetFocusedElement (getter_AddRefs (link));
-	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && link, FALSE);
-
-	/* ensure this is really a link so we don't accidentally submit if we're on a button or so! */
-	nsCOMPtr<nsIDOMHTMLAnchorElement> anchor (do_QueryInterface (link));
-	if (!anchor) return FALSE;
-#endif /* HAVE_TYPEAHEADFIND && HAVE_GECKO_1_8 */
+	if (NS_FAILED (rv) || !link) return FALSE;
 
 	nsCOMPtr<nsIDOMDocument> doc;
 	rv = link->GetOwnerDocument (getter_AddRefs (doc));
@@ -238,19 +242,20 @@ EphyFind::ActivateLink (GdkModifierType aMask)
 	NS_ENSURE_TRUE (docEvent, FALSE);
 
 	nsCOMPtr<nsIDOMEvent> event;
-	rv = docEvent->CreateEvent (nsEmbedString(kKeyEvents), getter_AddRefs (event));
+	rv = docEvent->CreateEvent (nsString(kKeyEvents), getter_AddRefs (event));
 	NS_ENSURE_SUCCESS (rv, FALSE);
 
 	nsCOMPtr<nsIDOMKeyEvent> keyEvent (do_QueryInterface (event));
 	NS_ENSURE_TRUE (keyEvent, FALSE);
 
-	rv = keyEvent->InitKeyEvent (nsEmbedString (kKeyPress),
+	rv = keyEvent->InitKeyEvent (nsString (kKeyPress),
 				     PR_TRUE /* bubble */,
 				     PR_TRUE /* cancelable */,
 				     abstractView,
 				     (aMask & GDK_CONTROL_MASK) != 0,
 				     (aMask & GDK_MOD1_MASK) != 0 /* Alt */,
 				     (aMask & GDK_SHIFT_MASK) != 0,
+				     /* FIXME when we upgrade to gtk 2.10 */
 				     PR_FALSE /* Meta */,
 				     nsIDOMKeyEvent::DOM_VK_RETURN,
 				     0);
