@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005 Christian Persch
+ *  Copyright © 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyFind.h,v 1.5 2006/05/10 18:07:00 chpe Exp $
+ *  $Id: EphyFind.h 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #ifndef TYPEAHEADFIND_H
@@ -53,7 +53,8 @@ class EphyFind
     nsCOMPtr<nsIWebBrowser> mWebBrowser;
 
     nsCOMPtr<nsITypeAheadFind> mFinder;
-    PRBool mAttention;
+    PRPackedBool mAttention;
+    PRPackedBool mHasFocus;
 };
 
 #endif /* !TYPEAHEADFIND_H */
