@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005, 2006 Christian Persch
+ *  Copyright © 2005, 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -9,13 +9,13 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyPromptService.h,v 1.1 2006/01/12 23:21:14 chpe Exp $
+ *  $Id: EphyPromptService.h 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #ifndef EPHY_PROMPT_SERVICE_H
@@ -23,6 +23,10 @@
 
 #include <nsIPromptService.h>
 
+#if HAVE_NSINONBLOCKINGALERTSERVICE_H
+#include <nsINonBlockingAlertService.h>
+#endif
+
 #define EPHY_PROMPT_SERVICE_IID				\
 { /* 6e8b90d4-78a6-41c5-98da-b1559a40d30d */		\
   0x6e8b90d4, 0x78a6, 0x41c5,				\
@@ -31,11 +35,17 @@
 #define EPHY_PROMPT_SERVICE_CLASSNAME	"Epiphany Prompt Service"
 
 class EphyPromptService : public nsIPromptService
+#if HAVE_NSINONBLOCKINGALERTSERVICE_H
+			, public nsINonBlockingAlertService
+#endif
 {
 public:
 	NS_DECL_ISUPPORTS
 	NS_DECL_NSIPROMPTSERVICE
-	
+#if HAVE_NSINONBLOCKINGALERTSERVICE_H
+	NS_DECL_NSINONBLOCKINGALERTSERVICE
+#endif
+
 	EphyPromptService();
 	virtual ~EphyPromptService();
 };
