@@ -1,7 +1,7 @@
 /*
  *  GtkNSSClientAuthDialogs.cpp
  *
- *  Copyright (C) 2003 Crispin Flowerday <gnome@flowerday.cx>
+ *  Copyright © 2003 Crispin Flowerday <gnome@flowerday.cx>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSClientAuthDialogs.cpp,v 1.28 2006/05/10 18:07:00 chpe Exp $
+ *  $Id: GtkNSSClientAuthDialogs.cpp 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -57,6 +57,7 @@
 #include "ephy-state.h"
 
 #include "AutoJSContextStack.h"
+#include "AutoWindowModalState.h"
 #include "EphyUtils.h"
 
 #include "GtkNSSClientAuthDialogs.h"
@@ -149,9 +150,11 @@ GtkNSSClientAuthDialogs::ChooseCertificate (nsIInterfaceRequestor *ctx,
 	rv = stack.Init ();
 	if (NS_FAILED (rv)) return rv;
 
-	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
+	nsCOMPtr<nsIDOMWindow> parent (do_GetInterface (ctx));
 	GtkWindow *gparent = GTK_WINDOW (EphyUtils::FindGtkParent (parent));
 
+	AutoWindowModalState modalState (parent);
+
 	dialog = gtk_dialog_new_with_buttons ("",
 					      GTK_WINDOW (gparent),
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -197,14 +200,9 @@ GtkNSSClientAuthDialogs::ChooseCertificate (nsIInterfaceRequestor *ctx,
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	
-
-	nsCString utf8_cn;
-	NS_UTF16ToCString (nsString (cn),
-			   NS_CSTRING_ENCODING_UTF8, utf8_cn);
 
 	msg = g_markup_printf_escaped (_("Choose a certificate to present as identification to “%s”."),
-				       utf8_cn.get());
+				       NS_ConvertUTF16toUTF8 (cn).get());
 	markup_text = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
 				       _("Select a certificate to identify yourself."),
 				       msg);
@@ -216,18 +214,10 @@ GtkNSSClientAuthDialogs::ChooseCertificate (nsIInterfaceRequestor *ctx,
 	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
 	for (i = 0; i < count; i++)
 	{
-		nsCString certnick;
-		nsCString certdetail;
-
-		NS_UTF16ToCString (nsString (certNickList[i]),
-				   NS_CSTRING_ENCODING_UTF8, certnick);
-		NS_UTF16ToCString (nsString (certDetailsList[i]),
-				   NS_CSTRING_ENCODING_UTF8, certdetail);
-
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter,
-				    0, certnick.get(),
-				    1, certdetail.get(),
+				    0, NS_ConvertUTF16toUTF8 (certNickList[i]).get(),
+				    1, NS_ConvertUTF16toUTF8 (certDetailsList[i]).get(),
 				    -1);
 	}
 
