@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2001,2002,2003 Philip Langdale
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2004, 2005 Christian Persch
+ *  Copyright © 2001,2002,2003 Philip Langdale
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozRegisterComponents.cpp,v 1.52 2006/06/23 20:50:40 jframeau Exp $
+ *  $Id: MozRegisterComponents.cpp 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -73,6 +73,7 @@
 #include "GtkNSSDialogs.h"
 #include "GtkNSSKeyPairDialogs.h"
 #include "GtkNSSSecurityWarningDialogs.h"
+#include "GeckoFormSigningDialog.h"
 #endif
 
 NS_GENERIC_FACTORY_CONSTRUCTOR(EphyAboutModule)
@@ -98,6 +99,7 @@ NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSClientAuthDialogs)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSDialogs)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSKeyPairDialogs)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSSecurityWarningDialogs)
+NS_GENERIC_FACTORY_CONSTRUCTOR(GeckoFormSigningDialog)
 #endif
 
 #define XPINSTALL_CONTRACTID NS_CONTENT_HANDLER_CONTRACTID_PREFIX "application/x-xpinstall"
@@ -182,6 +184,24 @@ static const nsModuleComponentInfo sAppComps[] = {
 		NS_CERTIFICATEDIALOGS_CONTRACTID,
 		GtkNSSDialogsConstructor
 	},
+	{
+		GTK_NSSDIALOGS_CLASSNAME,
+		GTK_NSSDIALOGS_CID,
+		NS_DOMCRYPTODIALOGS_CONTRACTID,
+		GtkNSSDialogsConstructor
+	},
+	{
+		GTK_NSSDIALOGS_CLASSNAME,
+		GTK_NSSDIALOGS_CID,
+		NS_TOKENDIALOGS_CONTRACTID,
+		GtkNSSDialogsConstructor
+	},
+	{
+		GTK_NSSDIALOGS_CLASSNAME,
+		GTK_NSSDIALOGS_CID,
+		NS_TOKENPASSWORDSDIALOG_CONTRACTID,
+		GtkNSSDialogsConstructor
+	},
 	{
 		GTK_NSSKEYPAIRDIALOGS_CLASSNAME,
 		GTK_NSSKEYPAIRDIALOGS_CID,
@@ -194,7 +214,13 @@ static const nsModuleComponentInfo sAppComps[] = {
 		NS_SECURITYWARNINGDIALOGS_CONTRACTID,
 		GtkNSSSecurityWarningDialogsConstructor
 	},
-#endif
+	{
+		GECKO_FORMSIGNINGDIALOGS_CLASSNAME,
+		GECKO_FORMSIGNINGDIALOGS_CID,
+		NS_FORMSIGNINGDIALOG_CONTRACTID,
+		GeckoFormSigningDialogConstructor
+	},
+#endif /* HAVE_MOZILLA_PSM */
 	{
 		NS_IHELPERAPPLAUNCHERDLG_CLASSNAME,
 		G_CONTENTHANDLER_CID,
