@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000, 2001, 2002 Marco Pesenti Gritti
+ *  Copyright © 2000, 2001, 2002 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-persist.cpp,v 1.56 2006/05/10 18:07:00 chpe Exp $
+ *  $Id: mozilla-embed-persist.cpp 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -80,7 +80,7 @@ mozilla_embed_persist_get_type (void)
 
         if (G_UNLIKELY (type == 0))
         {
-                static const GTypeInfo our_info =
+                const GTypeInfo our_info =
                 {
                         sizeof (MozillaEmbedPersistClass),
                         NULL, /* base_init */
