@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Robert Marcano
- *  Copyright (C) 2005 Crispin Flowerday
+ *  Copyright © 2003 Robert Marcano
+ *  Copyright © 2005 Crispin Flowerday
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: mozilla-x509-cert.cpp,v 1.3 2006/05/15 18:12:31 chpe Exp $
+ * $Id: mozilla-x509-cert.cpp 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -56,7 +56,7 @@ mozilla_x509_cert_get_type (void)
 
 	if (mozilla_x509_cert_type == 0)
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (MozillaX509CertClass),
 			NULL, /* base_init */
@@ -69,7 +69,7 @@ mozilla_x509_cert_get_type (void)
 			(GInstanceInitFunc) mozilla_x509_cert_init
 		};
 
-		static const GInterfaceInfo x509_cert_info =
+		const GInterfaceInfo x509_cert_info =
 		{
 			(GInterfaceInitFunc) ephy_x509_cert_init,      /* interface_init */
 			NULL,                                          /* interface_finalize */
