@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003, 2004  Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004, 2005  Christian Persch
+ *  Copyright © 2003, 2004  Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2005  Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: egg-editable-toolbar.c,v 1.91 2006/03/28 20:06:55 chpe Exp $
+ *  $Id: egg-editable-toolbar.c 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "config.h"
@@ -109,7 +109,7 @@ egg_editable_toolbar_get_type (void)
 
   if (G_UNLIKELY (type == 0))
     {
-      static const GTypeInfo our_info = {
+      const GTypeInfo our_info = {
 	sizeof (EggEditableToolbarClass),
 	NULL,			/* base_init */
 	NULL,			/* base_finalize */
@@ -532,6 +532,9 @@ action_sensitive_cb (GtkAction   *action,
   EggEditableToolbar *etoolbar = EGG_EDITABLE_TOOLBAR
     (gtk_widget_get_ancestor (GTK_WIDGET (item), EGG_TYPE_EDITABLE_TOOLBAR));
 
+  if (etoolbar == NULL)
+    return;
+
   if (etoolbar->priv->edit_mode > 0)
     {
       gtk_widget_set_sensitive (GTK_WIDGET (item), TRUE);
