@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2002 Jorn Baayen <jorn@nl.linux.org>
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-db.h,v 1.10 2004/04/04 18:30:33 adamh Exp $
+ *  $Id: ephy-node-db.h 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #ifndef EPHY_NODE_DB_H
@@ -35,7 +35,7 @@ G_BEGIN_DECLS
 #define EPHY_NODE_DB_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_NODE_DB, EphyNodeDbClass))
 
 typedef struct _EphyNodeDb EphyNodeDb;
-typedef struct EphyNodeDbPrivate EphyNodeDbPrivate;
+typedef struct _EphyNodeDbPrivate EphyNodeDbPrivate;
 
 struct _EphyNodeDb
 {
@@ -55,8 +55,6 @@ typedef struct
 
 GType         ephy_node_db_get_type		(void);
 
-EphyNodeDb   *ephy_node_db_get_by_name		(const char *name);
-
 EphyNodeDb   *ephy_node_db_new			(const char *name);
 
 gboolean      ephy_node_db_load_from_file	(EphyNodeDb *db,
