@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2002 Jorn Baayen
+ *  Copyright © 2002 Jorn Baayen
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-stock-icons.h,v 1.15 2005/10/20 13:12:56 chpe Exp $
+ *  $Id: ephy-stock-icons.h 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #ifndef EPHY_STOCK_ICONS_H
@@ -23,23 +23,23 @@
 
 G_BEGIN_DECLS
 
-#define EPHY_ICON_SIZE_TAB_BUTTON "epiphany-icon-size-tab-button"
-
-#define EPHY_STOCK_CLOSE_TAB	   "epiphany-close-tab"
 #define EPHY_STOCK_POPUPS	   "epiphany-popup-hidden"
 #define EPHY_STOCK_HISTORY         "epiphany-history"
 #define EPHY_STOCK_BOOKMARKS       "epiphany-bookmarks"
 #define EPHY_STOCK_ENTRY	   "epiphany-entry"
 #define EPHY_STOCK_DOWNLOAD	   "epiphany-download"
 
-#define STOCK_NEW_TAB		   "stock_new-tab"
+#define STOCK_NEW_TAB              "tab-new"
+#define STOCK_NEW_WINDOW           "window-new"
 #define STOCK_VIEW_SOURCE	   "stock_view-html-source"
-#define STOCK_SEND_MAIL		   "stock_mail-send"
-#define STOCK_ADD_BOOKMARK	   "stock_add-bookmark"
-#define STOCK_PRINT_SETUP	   "stock_print-setup"
-#define STOCK_LOCK_INSECURE	   "stock_lock-open"
-#define STOCK_LOCK_SECURE	   "stock_lock"
+#define STOCK_SEND_MAIL            "mail-forward"
+#define STOCK_ADD_BOOKMARK         "bookmark-new"
+#define STOCK_BOOKMARK             "stock_bookmark"
+#define STOCK_PRINT_SETUP          "stock_print-setup" /*document-page-setup*/
+#define STOCK_LOCK_INSECURE        "stock_lock-open"
+#define STOCK_LOCK_SECURE          "stock_lock"
 #define STOCK_LOCK_BROKEN	   "stock_lock-broken"
+#define STOCK_DRAG_MODE	   	   "stock_drag-mode"
 
 void ephy_stock_icons_init (void);
 
