@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
+ *  Copyright © 2002 Jorn Baayen <jorn@nl.linux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-view.h,v 1.16 2005/01/21 19:33:02 jbaayen Exp $
+ *  $Id: ephy-node-view.h 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #ifndef __EPHY_NODE_VIEW_H
@@ -112,13 +112,13 @@ void	   ephy_node_view_select_node         (EphyNodeView *view,
 			                       EphyNode *node);
 
 void	   ephy_node_view_enable_drag_source  (EphyNodeView *view,
-					       GtkTargetEntry *types,
+					       const GtkTargetEntry *types,
 					       int n_types,
 					       int base_drag_column_id,
 					       int extra_drag_column_id);
 
 void	   ephy_node_view_enable_drag_dest    (EphyNodeView *view,
-					       GtkTargetEntry *types,
+					       const GtkTargetEntry *types,
 					       int n_types);
 
 void	   ephy_node_view_edit		      (EphyNodeView *view,
