@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-zoom-action.c,v 1.11 2005/01/08 19:41:47 chpe Exp $
+ *  $Id: ephy-zoom-action.c 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "config.h"
@@ -66,7 +66,7 @@ ephy_zoom_action_get_type (void)
 
         if (G_UNLIKELY (type == 0))
         {
-                static const GTypeInfo our_info =
+                const GTypeInfo our_info =
 			{
 				sizeof (EphyZoomActionClass),
 				NULL, /* base_init */
@@ -232,7 +232,7 @@ ephy_zoom_action_class_init (EphyZoomActionClass *class)
 							     ZOOM_MINIMAL,
 							     ZOOM_MAXIMAL,
 							     1.0,
-							     G_PARAM_READWRITE));
+							     G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	signals[ZOOM_TO_LEVEL_SIGNAL] =
 		g_signal_new ("zoom_to_level",
