@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004 Peter Harvey
+ *  Copyright © 2004 Peter Harvey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-factory-action.c,v 1.5 2006/02/12 13:56:23 chpe Exp $
+ *  $Id: ephy-topic-factory-action.c 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -46,7 +46,7 @@ ephy_topic_factory_action_get_type (void)
 
 	if (!type)
 	{
-		static const GTypeInfo type_info =
+		const GTypeInfo type_info =
 		{
 			sizeof (EphyTopicFactoryActionClass),
 			(GBaseInitFunc) NULL,
