@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2002-2004 Marco Pesenti Gritti <mpeseng@tin.it>
- *  Copyright (C) 2005 Peter Harvey <pah06@uow.edu.au>
+ *  Copyright © 2002-2004 Marco Pesenti Gritti <mpeseng@tin.it>
+ *  Copyright © 2005 Peter Harvey <pah06@uow.edu.au>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topics-palette.c,v 1.8 2006/02/24 12:13:57 paharvey Exp $
+ *  $Id: ephy-topics-palette.c 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "config.h"
@@ -77,7 +77,7 @@ ephy_topics_palette_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyTopicsPaletteClass),
 			NULL,
