@@ -1,5 +1,5 @@
 /* 
- *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
+ *  Copyright © 2002 Jorn Baayen <jorn@nl.linux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-completion-model.c,v 1.16 2004/11/02 20:57:20 chpe Exp $
+ *  $Id: ephy-completion-model.c 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "config.h"
@@ -31,7 +31,7 @@ static void ephy_completion_model_tree_model_init (GtkTreeModelIface *iface);
 
 #define EPHY_COMPLETION_MODEL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_COMPLETION_MODEL, EphyCompletionModelPrivate))
 
-struct EphyCompletionModelPrivate
+struct _EphyCompletionModelPrivate
 {
 	EphyNode *history;
 	EphyNode *bookmarks;
@@ -53,7 +53,7 @@ ephy_completion_model_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyCompletionModelClass),
 			NULL,
@@ -66,7 +66,7 @@ ephy_completion_model_get_type (void)
 			(GInstanceInitFunc) ephy_completion_model_init
 		};
 
-		static const GInterfaceInfo tree_model_info =
+		const GInterfaceInfo tree_model_info =
 		{
 			(GInterfaceInitFunc) ephy_completion_model_tree_model_init,
 			NULL,
