@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000, 2001, 2002, 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2000, 2001, 2002, 2003 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-encoding-dialog.c,v 1.22 2005/10/30 22:58:12 chpe Exp $
+ *  $Id: ephy-encoding-dialog.c 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "config.h"
@@ -85,7 +85,7 @@ ephy_encoding_dialog_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyEncodingDialogClass),
 			NULL, /* base_init */
@@ -107,7 +107,7 @@ ephy_encoding_dialog_get_type (void)
 }
 
 static void
-sync_embed_cb (EphyEncodingDialog *dialog, GParamSpec *pspec, gpointer dummy)
+sync_encoding_against_embed (EphyEncodingDialog *dialog)
 {
 	EphyEmbed *embed;
 	EphyNode *node;
@@ -160,6 +160,33 @@ sync_embed_cb (EphyEncodingDialog *dialog, GParamSpec *pspec, gpointer dummy)
 	dialog->priv->update_tag = FALSE;
 }
 
+
+static void
+embed_net_stop_cb (EphyEmbed *embed, EphyEncodingDialog *dialog)
+{
+	sync_encoding_against_embed (dialog);
+}
+
+static void
+sync_embed_cb (EphyEncodingDialog *dialog, GParamSpec *pspec, gpointer dummy)
+{
+	EphyEmbed *embed;
+	embed = ephy_embed_dialog_get_embed (EPHY_EMBED_DIALOG (dialog));
+
+	if (dialog->priv->embed != NULL)
+	{
+		g_signal_handlers_disconnect_by_func (dialog->priv->embed,
+						      G_CALLBACK (embed_net_stop_cb),
+						      dialog);
+	}
+
+	g_signal_connect (G_OBJECT (embed), "net_stop",
+			  G_CALLBACK (embed_net_stop_cb), dialog);
+	dialog->priv->embed = embed;
+
+	sync_encoding_against_embed (dialog);
+}
+
 static void
 sync_active_tab (EphyWindow *window, GParamSpec *pspec, EphyEncodingDialog *dialog)
 {
@@ -367,6 +394,13 @@ ephy_encoding_dialog_finalize (GObject *object)
 						      dialog);
 	}
 
+	if (dialog->priv->embed)
+	{
+		g_signal_handlers_disconnect_by_func (dialog->priv->embed,
+						      G_CALLBACK (embed_net_stop_cb),
+						      dialog);
+	}
+
 	g_object_unref (dialog->priv->filter);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
