@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-extension.c,v 1.6 2004/11/02 20:57:21 chpe Exp $
+ *  $Id: ephy-extension.c 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "config.h"
@@ -30,7 +30,7 @@ ephy_extension_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyExtensionIface),
 			NULL,
@@ -50,7 +50,10 @@ ephy_extension_attach_window (EphyExtension *extension,
 			      EphyWindow *window)
 {
 	EphyExtensionIface *iface = EPHY_EXTENSION_GET_IFACE (extension);
-	iface->attach_window (extension, window);
+	if (iface->attach_window)
+	{
+		iface->attach_window (extension, window);
+	}
 }
 
 void
@@ -58,5 +61,32 @@ ephy_extension_detach_window (EphyExtension *extension,
 			      EphyWindow *window)
 {
 	EphyExtensionIface *iface = EPHY_EXTENSION_GET_IFACE (extension);
-	iface->detach_window (extension, window);
+	if (iface->detach_window)
+	{
+		iface->detach_window (extension, window);
+	}
+}
+
+void
+ephy_extension_attach_tab (EphyExtension *extension,
+			   EphyWindow *window,
+			   EphyTab *tab)
+{
+	EphyExtensionIface *iface = EPHY_EXTENSION_GET_IFACE (extension);
+	if (iface->attach_tab)
+	{
+		iface->attach_tab (extension, window, tab);
+	}
+}
+
+void
+ephy_extension_detach_tab (EphyExtension *extension,
+			   EphyWindow *window,
+			   EphyTab *tab)
+{
+	EphyExtensionIface *iface = EPHY_EXTENSION_GET_IFACE (extension);
+	if (iface->detach_tab)
+	{
+		iface->detach_tab (extension, window, tab);
+	}
 }
