@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2002 Jorn Baayen
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004, 2005, 2006 Christian Persch
+ *  Copyright © 2002 Jorn Baayen
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2005, 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-session.c,v 1.50 2006/01/29 21:47:21 chpe Exp $
+ *  $Id: ephy-session.c 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "config.h"
@@ -36,9 +36,7 @@
 #include "ephy-debug.h"
 
 #include <glib/gi18n.h>
-#include <errno.h>
-#include <string.h>
-#include <stdlib.h>
+#include <gtk/gtkmain.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkstock.h>
@@ -46,11 +44,27 @@
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkmessagedialog.h>
+
+#include <libgnomeui/gnome-client.h>
+
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
+
 #include <libxml/tree.h>
 #include <libxml/xmlwriter.h>
 
+#include <errno.h>
+#include <string.h>
+#include <stdlib.h>
+
+typedef struct
+{
+	EphySessionCommand command;
+	char *arg;
+	char **args;
+	guint32 user_time;
+} SessionCommand;
+
 #define EPHY_SESSION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SESSION, EphySessionPrivate))
 
 struct _EphySessionPrivate
@@ -58,6 +72,10 @@ struct _EphySessionPrivate
 	GList *windows;
 	GList *tool_windows;
 	GtkWidget *resume_dialog;
+
+	GQueue *queue;
+	guint queue_idle_id;
+
 	guint dont_save : 1;
 	guint quit_while_resuming : 1;
 };
@@ -69,6 +87,7 @@ struct _EphySessionPrivate
 static void ephy_session_class_init	(EphySessionClass *klass);
 static void ephy_session_iface_init	(EphyExtensionIface *iface);
 static void ephy_session_init		(EphySession *session);
+static void session_command_queue_next	(EphySession *session);
 
 enum
 {
@@ -85,7 +104,7 @@ ephy_session_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphySessionClass),
 			NULL, /* base_init */
@@ -98,7 +117,7 @@ ephy_session_get_type (void)
 			(GInstanceInitFunc) ephy_session_init
 		};
 
-		static const GInterfaceInfo extension_info =
+		const GInterfaceInfo extension_info =
 		{
 			(GInterfaceInitFunc) ephy_session_iface_init,
 			NULL,
@@ -117,6 +136,256 @@ ephy_session_get_type (void)
 	return type;
 }
 
+/* Gnome session client */
+
+typedef struct
+{
+	GtkWidget *dialog;
+	GtkWidget *label;
+	guint timeout_id;
+	guint ticks;
+	int response;
+	int key;
+} InteractData;
+
+static void
+confirm_shutdown_dialog_update_timeout_label (InteractData *data)
+{
+	char *text;
+
+	text = g_strdup_printf (ngettext ("Downloads will be aborted and logout proceed in %d second.",
+					  "Downloads will be aborted and logout proceed in %d seconds.",
+					  data->ticks),
+				data->ticks);
+
+	gtk_label_set_text (GTK_LABEL (data->label), text);
+	g_free (text);
+}
+		
+static gboolean
+confirm_shutdown_dialog_tick_cb (InteractData *data)
+{
+	if (data->ticks > 0)
+	{
+		--data->ticks;
+		confirm_shutdown_dialog_update_timeout_label (data);
+		return TRUE;
+	}
+
+	data->timeout_id = 0;
+	gtk_dialog_response (GTK_DIALOG (data->dialog),
+			     GTK_RESPONSE_ACCEPT);
+	return FALSE;
+}
+
+static void
+confirm_shutdown_dialog_response_cb (GtkWidget *dialog,
+				     int response,
+				     InteractData *data)
+{
+	LOG ("confirm_shutdown_dialog_response_cb response %d", response);
+
+	data->response = response;
+
+	gtk_widget_destroy (dialog);
+}
+
+static void
+confirm_shutdown_dialog_accept_cb (InteractData *data,
+				   GObject *zombie)
+{
+	gtk_dialog_response (GTK_DIALOG (data->dialog),
+			     GTK_RESPONSE_ACCEPT);
+}
+
+static void
+confirm_shutdown_dialog_weak_ref_cb (InteractData *data,
+				     GObject *zombie)
+{
+	EphyShell *shell;
+	GObject *dv;
+	int key;
+	gboolean cancel_shutdown;
+
+	LOG ("confirm_shutdown_dialog_weak_ref_cb response %d", data->response);
+
+	shell = ephy_shell_get_default ();
+	if (shell != NULL)
+	{
+		g_object_weak_unref (G_OBJECT (shell),
+				     (GWeakNotify) confirm_shutdown_dialog_accept_cb,
+				     data);
+
+		dv = ephy_embed_shell_get_downloader_view_nocreate (ephy_embed_shell_get_default ());
+		if (dv != NULL)
+		{
+			g_object_weak_unref (dv,
+					     (GWeakNotify) confirm_shutdown_dialog_accept_cb,
+					     data);
+		}
+	}
+
+	if (data->timeout_id != 0)
+	{
+		g_source_remove (data->timeout_id);
+	}
+
+	key = data->key;
+	cancel_shutdown = data->response != GTK_RESPONSE_ACCEPT;
+
+	g_free (data);
+
+	gnome_interaction_key_return (key, cancel_shutdown);
+}
+
+static void
+confirm_shutdown_cb (GnomeClient *client,
+		     int key,
+		     GnomeDialogType dialog_type,
+		     gpointer user_data)
+{
+	GObject *dv;
+	GtkWidget *dialog, *box;
+	InteractData *data;
+
+	/* FIXME: Can this happen: We already quit? */
+	if (ephy_shell_get_default () == NULL)
+	{
+		gnome_interaction_key_return (key, FALSE);
+		return;
+	}
+
+	dv = ephy_embed_shell_get_downloader_view_nocreate (ephy_embed_shell_get_default ());
+
+	/* Check if there are still downloads pending */
+	if (dv == NULL)
+	{
+		gnome_interaction_key_return (key, FALSE);
+		return;
+	}
+
+	dialog = gtk_message_dialog_new
+		(NULL,
+		 GTK_DIALOG_MODAL,
+		 GTK_MESSAGE_WARNING,
+		 GTK_BUTTONS_NONE,
+		 _("Abort pending downloads?"));
+
+	gtk_message_dialog_format_secondary_text
+		(GTK_MESSAGE_DIALOG (dialog),
+		 _("There are still downloads pending. If you log out, "
+		   "they will be aborted and lost."));
+
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       _("_Cancel Logout"), GTK_RESPONSE_REJECT);
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       _("_Abort Downloads"), GTK_RESPONSE_ACCEPT);
+
+	gtk_window_set_title (GTK_WINDOW (dialog), "");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_REJECT);
+
+	data = g_new (InteractData, 1);
+	data->dialog = dialog;
+	data->response = GTK_RESPONSE_REJECT;
+	data->key = key;
+
+	/* This isn't very exact, but it's good enough here */
+	data->timeout_id = g_timeout_add (1000,
+					  (GSourceFunc) confirm_shutdown_dialog_tick_cb,
+					  data);
+	data->ticks = 60;
+
+	/* Add timeout label */
+	data->label = gtk_label_new (NULL);
+	gtk_label_set_line_wrap (GTK_LABEL (data->label), TRUE);
+	confirm_shutdown_dialog_update_timeout_label (data);
+
+	box = ephy_gui_message_dialog_get_content_box (dialog);
+	gtk_box_pack_end (GTK_BOX (box), data->label, FALSE, FALSE, 0);
+	gtk_widget_show (data->label);
+
+	/* When we're quitting, un-veto the shutdown  */
+	g_object_weak_ref (G_OBJECT (ephy_shell_get_default ()),
+			   (GWeakNotify) confirm_shutdown_dialog_accept_cb,
+			   data);
+
+	/* When the download finishes, un-veto the shutdown */
+	g_object_weak_ref (dv,
+			   (GWeakNotify) confirm_shutdown_dialog_accept_cb,
+			   data);
+
+	g_signal_connect (dialog, "response",
+			  G_CALLBACK (confirm_shutdown_dialog_response_cb), data);
+	g_object_weak_ref (G_OBJECT (dialog),
+			   (GWeakNotify) confirm_shutdown_dialog_weak_ref_cb,
+			   data);
+
+	gtk_window_present (GTK_WINDOW (dialog));
+}
+
+static gboolean
+save_yourself_cb (GnomeClient *client,
+		  int phase,
+		  GnomeSaveStyle save_style,
+		  gboolean shutdown,
+		  GnomeInteractStyle interact_style,
+		  gboolean fast,
+		  EphySession *session)
+{
+	char *argv[] = { NULL, "--load-session", NULL };
+	char *discard_argv[] = { "rm", "-f", NULL };
+	char *tmp, *save_to;
+
+	LOG ("save_yourself_cb");
+
+	tmp = g_build_filename (ephy_dot_dir (),
+				"session_gnome-XXXXXX",
+				NULL);
+	save_to = ephy_file_tmp_filename (tmp, "xml");
+	g_free (tmp);
+
+	argv[0] = g_get_prgname ();
+	argv[2] = save_to;
+	gnome_client_set_restart_command
+		(client, 3, argv);
+
+	discard_argv[2] = save_to;
+	gnome_client_set_discard_command (client, 3,
+					  discard_argv);
+
+	ephy_session_save (session, save_to);
+
+	g_free (save_to);
+
+	/* If we're shutting down, check if there are downloads
+	 * remaining, since they can't be restarted.
+	 */
+	if (shutdown &&
+	    ephy_embed_shell_get_downloader_view_nocreate (ephy_embed_shell_get_default ()) != NULL)
+	{
+		gnome_client_request_interaction (client,
+						  GNOME_DIALOG_NORMAL,
+						  (GnomeInteractFunction) confirm_shutdown_cb,
+						  session);
+	}
+
+	return TRUE;
+}
+
+static void
+die_cb (GnomeClient* client,
+	EphySession *session)
+	
+{
+	LOG ("die_cb");
+
+	ephy_session_close (session);
+}
+
+/* Helper functions */
+
 static char *
 get_session_filename (const char *filename)
 {
@@ -162,18 +431,20 @@ net_stop_cb (EphyEmbed *embed,
 }
 
 static void
-tab_added_cb (GtkWidget *notebook,
-	      EphyTab *tab,
-	      EphySession *session)
+notebook_page_added_cb (GtkWidget *notebook,
+			EphyTab *tab,
+			guint position,
+			EphySession *session)
 {
 	g_signal_connect (ephy_tab_get_embed (tab), "net-stop",
 			  G_CALLBACK (net_stop_cb), session);
 }
 
 static void
-tab_removed_cb (GtkWidget *notebook,
-		EphyTab *tab,
-		EphySession *session)
+notebook_page_removed_cb (GtkWidget *notebook,
+			  EphyTab *tab,
+			  guint position,
+			  EphySession *session)
 {
 	ephy_session_save (session, SESSION_CRASHED);
 
@@ -182,8 +453,10 @@ tab_removed_cb (GtkWidget *notebook,
 }
 
 static void
-tabs_reordered_cb (GtkWidget *notebook,
-		   EphySession *session)
+notebook_page_reordered_cb (GtkWidget *notebook,
+			    GtkWidget *tab,
+			    guint position,
+			    EphySession *session)
 {
 	ephy_session_save (session, SESSION_CRASHED);
 }
@@ -207,6 +480,335 @@ window_focus_in_event_cb (EphyWindow *window,
 	return FALSE;
 }
 
+/* Queue worker */
+
+static void
+session_command_free (SessionCommand *cmd)
+{
+	g_assert (cmd != NULL);
+
+	g_free (cmd->arg);
+	if (cmd->args)
+	{
+		g_strfreev (cmd->args);
+	}
+
+	g_free (cmd);
+
+	g_object_unref (ephy_shell_get_default ());
+}
+
+static int
+session_command_find (const SessionCommand *cmd,
+		      gpointer cmdptr)
+{
+	EphySessionCommand command = GPOINTER_TO_INT (cmdptr);
+
+	return command != cmd->command;
+}
+
+static void
+resume_dialog_response_cb (GtkWidget *dialog,
+			   int response,
+			   EphySession *session)
+{
+	guint32 user_time;
+
+	LOG ("resume_dialog_response_cb response:%d", response);
+
+	gtk_widget_hide (dialog);
+
+	user_time = gtk_get_current_event_time ();
+
+	if (response == GTK_RESPONSE_ACCEPT)
+	{
+		ephy_session_queue_command (session,
+				  	    EPHY_SESSION_CMD_LOAD_SESSION,
+					    SESSION_CRASHED, NULL,
+					    user_time, TRUE);
+	}
+
+	ephy_session_queue_command (session,
+				    EPHY_SESSION_CMD_MAYBE_OPEN_WINDOW,
+				    NULL, NULL, user_time, FALSE);
+
+	gtk_widget_destroy (dialog);
+}
+
+static void
+resume_dialog_weak_ref_cb (EphySession *session,
+			   GObject *zombie)
+{
+	EphySessionPrivate *priv = session->priv;
+
+	LOG ("resume_dialog_weak_ref_cb");
+
+	priv->resume_dialog = NULL;
+
+	gtk_window_set_auto_startup_notification (TRUE);
+
+	session_command_queue_next (session);
+
+	g_object_unref (ephy_shell_get_default ());
+}
+
+static void
+session_command_autoresume (EphySession *session,
+			    guint32 user_time)
+{
+	EphySessionPrivate *priv = session->priv;
+	GtkWidget *dialog;
+	char *saved_session;
+	gboolean crashed_session;
+
+	LOG ("ephy_session_autoresume");
+
+	saved_session = get_session_filename (SESSION_CRASHED);
+	crashed_session = g_file_test (saved_session, G_FILE_TEST_EXISTS);
+	g_free (saved_session);
+
+	if (crashed_session == FALSE ||
+	    priv->windows != NULL ||
+	    priv->tool_windows != NULL)
+	{
+		/* FIXME can this happen? */
+		if (priv->resume_dialog != NULL)
+		{
+			gtk_widget_hide (priv->resume_dialog);
+			gtk_widget_destroy (priv->resume_dialog);
+		}
+
+		ephy_session_queue_command (session,
+					    EPHY_SESSION_CMD_MAYBE_OPEN_WINDOW,
+					    NULL, NULL, user_time, FALSE);
+
+		return;
+	}
+
+	if (priv->resume_dialog)
+	{
+		gtk_window_present_with_time (GTK_WINDOW (priv->resume_dialog),
+					      user_time);
+
+		return;
+	}
+
+	/* Ref the shell while we show the dialogue. The unref
+	 * happens in the weak ref notification when the dialogue
+	 * is destroyed.
+	 */
+	g_object_ref (ephy_shell_get_default ());
+
+	dialog = gtk_message_dialog_new
+		(NULL,
+		 GTK_DIALOG_MODAL,
+		 GTK_MESSAGE_WARNING,
+		 GTK_BUTTONS_NONE,
+		 _("Recover previous browser windows and tabs?"));
+
+	gtk_message_dialog_format_secondary_text
+		(GTK_MESSAGE_DIALOG (dialog),
+		 _("Epiphany appears to have exited unexpectedly the last time "
+		   "it was run. You can recover the opened windows and tabs."));
+	
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       _("_Don't Recover"), GTK_RESPONSE_CANCEL);
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       _("_Recover"), GTK_RESPONSE_ACCEPT);
+
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Crash Recovery"));
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
+	gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dialog), FALSE);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+
+	g_signal_connect (dialog, "response",
+			  G_CALLBACK (resume_dialog_response_cb), session);
+	g_object_weak_ref (G_OBJECT (dialog),
+			   (GWeakNotify) resume_dialog_weak_ref_cb,
+			   session);
+
+	/* FIXME ? */
+	gtk_window_set_auto_startup_notification (FALSE);
+
+	priv->resume_dialog = dialog;
+
+	gtk_window_present_with_time (GTK_WINDOW (dialog), user_time);
+}
+
+static void
+session_command_open_bookmarks_editor (EphySession *session,
+				       guint32 user_time)
+{
+	GtkWidget *editor;
+
+	editor = ephy_shell_get_bookmarks_editor (ephy_shell_get_default ());
+        
+	gtk_window_present_with_time (GTK_WINDOW (editor), user_time);
+}
+
+static void
+session_command_open_uris (EphySession *session,
+			   char **uris,
+			   const char *options,
+			   guint32 user_time)
+{
+	EphyShell *shell;
+	EphyWindow *window;
+	EphyTab *tab;
+	EphyNewTabFlags flags = 0;
+	guint i;
+
+	shell = ephy_shell_get_default ();
+
+	g_object_ref (shell);
+
+	window = ephy_session_get_active_window (session);
+
+	if (options != NULL && strstr (options, "new-window") != NULL)
+	{
+		window = NULL;
+		flags |= EPHY_NEW_TAB_IN_NEW_WINDOW;
+	}
+	else if (options != NULL && strstr (options, "new-tab") != NULL)
+	{
+		flags |= EPHY_NEW_TAB_IN_EXISTING_WINDOW |
+			 EPHY_NEW_TAB_JUMP;
+	}
+
+	for (i = 0; uris[i] != NULL; ++i)
+	{
+		const char *url = uris[i];
+		EphyNewTabFlags page_flags;
+
+		if (url[0] == '\0')
+		{
+			page_flags = EPHY_NEW_TAB_HOME_PAGE;
+		}
+		else
+		{
+			page_flags = EPHY_NEW_TAB_OPEN_PAGE;
+		}
+
+		tab = ephy_shell_new_tab_full (shell, window,
+					       NULL /* parent tab */,
+					       url,
+					       flags | page_flags,
+					       EPHY_EMBED_CHROME_ALL,
+					       FALSE /* is popup? */,
+					       user_time);
+
+		window = EPHY_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab)));
+	}
+
+	g_object_unref (shell);
+}
+
+static gboolean
+session_command_dispatch (EphySession *session)
+{
+	EphySessionPrivate *priv = session->priv;
+	SessionCommand *cmd;
+	gboolean run_again = TRUE;
+
+	cmd = g_queue_pop_head (priv->queue);
+	g_assert (cmd != NULL);
+
+	LOG ("dispatching queue cmd:%d", cmd->command);
+
+	switch (cmd->command)
+	{
+		case EPHY_SESSION_CMD_RESUME_SESSION:
+			session_command_autoresume (session, cmd->user_time);
+			break;
+		case EPHY_SESSION_CMD_LOAD_SESSION:
+			ephy_session_load (session, cmd->arg, cmd->user_time);
+			break;
+		case EPHY_SESSION_CMD_OPEN_BOOKMARKS_EDITOR:
+			session_command_open_bookmarks_editor (session, cmd->user_time);
+			break;
+		case EPHY_SESSION_CMD_OPEN_URIS:
+			session_command_open_uris (session, cmd->args, cmd->arg, cmd->user_time);
+			break;
+		case EPHY_SESSION_CMD_MAYBE_OPEN_WINDOW:
+			/* FIXME: maybe just check for normal windows? */
+			if (priv->windows == NULL &&
+			    priv->tool_windows == NULL)
+			{
+				ephy_shell_new_tab_full (ephy_shell_get_default (),
+							 NULL /* window */, NULL /* tab */,
+							 NULL /* URL */,
+							 EPHY_NEW_TAB_IN_NEW_WINDOW |
+							 EPHY_NEW_TAB_HOME_PAGE,
+							 EPHY_EMBED_CHROME_ALL,
+							 FALSE /* is popup? */,
+							 cmd->user_time);
+			}
+			break;
+		default:
+			g_assert_not_reached ();
+			break;
+	}
+
+	/* Look if there's anything else to dispatch */
+	if (g_queue_is_empty (priv->queue) ||
+	    priv->resume_dialog != NULL)
+	{
+		priv->queue_idle_id = 0;
+		run_again = FALSE;
+	}
+
+	/* This unrefs the shell! */
+	session_command_free (cmd);
+
+	return run_again;
+}
+
+static void
+session_command_queue_next (EphySession *session)
+{
+	EphySessionPrivate *priv = session->priv;
+
+	LOG ("queue_next");
+
+	if (!g_queue_is_empty (priv->queue) &&
+	    priv->resume_dialog == NULL &&
+	    priv->queue_idle_id == 0)
+	{
+		priv->queue_idle_id =
+			g_idle_add ((GSourceFunc) session_command_dispatch,
+				    session);
+	}
+}
+
+static void
+session_command_queue_clear (EphySession *session)
+{
+	EphySessionPrivate *priv = session->priv;
+
+	if (priv->resume_dialog != NULL)
+	{
+		gtk_widget_destroy (priv->resume_dialog);
+		/* destroying the resume dialogue will set this to NULL */
+		g_assert (priv->resume_dialog == NULL);
+	}
+
+	if (priv->queue_idle_id != 0)
+	{
+		g_source_remove (priv->queue_idle_id);
+		priv->queue_idle_id = 0;
+	}
+
+	if (priv->queue != NULL)
+	{
+		g_queue_foreach (priv->queue, (GFunc) session_command_free, NULL);
+		g_queue_free (priv->queue);
+		priv->queue = NULL;
+	}
+}
+
+/* EphyExtensionIface implementation */
+
 static void
 impl_attach_window (EphyExtension *extension,
 		    EphyWindow *window)
@@ -223,12 +825,12 @@ impl_attach_window (EphyExtension *extension,
 			  G_CALLBACK (window_focus_in_event_cb), session);
 
 	notebook = ephy_window_get_notebook (window);
-	g_signal_connect (notebook, "tab-added",
-			  G_CALLBACK (tab_added_cb), session);
-	g_signal_connect (notebook, "tab-removed",
-			  G_CALLBACK (tab_removed_cb), session);
-	g_signal_connect (notebook, "tabs-reordered",
-			  G_CALLBACK (tabs_reordered_cb), session);
+	g_signal_connect (notebook, "page-added",
+			  G_CALLBACK (notebook_page_added_cb), session);
+	g_signal_connect (notebook, "page-removed",
+			  G_CALLBACK (notebook_page_removed_cb), session);
+	g_signal_connect (notebook, "page-reordered",
+			  G_CALLBACK (notebook_page_reordered_cb), session);
 
 	/* Set unique identifier as role, so that on restore, the WM can
 	 * place the window on the right workspace
@@ -263,19 +865,33 @@ impl_detach_window (EphyExtension *extension,
 	 */
 }
 
+/* Class implementation */
+
 static void
 ephy_session_init (EphySession *session)
 {
-	session->priv = EPHY_SESSION_GET_PRIVATE (session);
+	EphySessionPrivate *priv;
+	GnomeClient *client;
 
 	LOG ("EphySession initialising");
+
+	priv = session->priv = EPHY_SESSION_GET_PRIVATE (session);
+
+	priv->queue = g_queue_new ();
+
+	client = gnome_master_client ();
+	g_signal_connect (client, "save-yourself",
+			  G_CALLBACK (save_yourself_cb), session);
+	g_signal_connect (client, "die",
+			  G_CALLBACK (die_cb), session);
 }
 
 static void
 ephy_session_dispose (GObject *object)
 {
-	EphySession *session = EPHY_SESSION(object);
+	EphySession *session = EPHY_SESSION (object);
 	EphySessionPrivate *priv = session->priv;
+	GnomeClient *client;
 
 	LOG ("EphySession disposing");
 
@@ -287,6 +903,14 @@ ephy_session_dispose (GObject *object)
 		session_delete (session, SESSION_CRASHED);
 	}
 
+	session_command_queue_clear (session);
+
+	client = gnome_master_client ();
+	g_signal_handlers_disconnect_by_func
+		(client, G_CALLBACK (save_yourself_cb), session);
+	g_signal_handlers_disconnect_by_func
+		(client, G_CALLBACK (die_cb), session);
+
 	parent_class->dispose (object);
 }
 
@@ -301,7 +925,7 @@ ephy_session_finalize (GObject *object)
 	g_list_free (session->priv->windows);
 	g_list_free (session->priv->tool_windows);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	parent_class->finalize (object);
 }
 
 static void
@@ -363,100 +987,7 @@ ephy_session_class_init (EphySessionClass *class)
 	g_type_class_add_private (object_class, sizeof (EphySessionPrivate));
 }
 
-static gboolean
-offer_to_resume (EphySession *session,
-		 guint32 user_time)
-{
-	GtkWidget *dialog;
-	int response;
-
-	dialog = gtk_message_dialog_new
-		(NULL,
-		 GTK_DIALOG_MODAL,
-		 GTK_MESSAGE_WARNING,
-		 GTK_BUTTONS_NONE,
-		 _("Recover previous browser windows and tabs?"));
-
-	gtk_message_dialog_format_secondary_text
-		(GTK_MESSAGE_DIALOG (dialog),
-		 _("Epiphany appears to have exited unexpectedly the last time "
-		   "it was run. You can recover the opened windows and tabs."));
-	
-	gtk_dialog_add_button (GTK_DIALOG (dialog),
-			       _("_Don't Recover"), GTK_RESPONSE_CANCEL);
-	gtk_dialog_add_button (GTK_DIALOG (dialog),
-			       _("_Recover"), GTK_RESPONSE_ACCEPT);
-
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Crash Recovery"));
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
-	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
-
-	session->priv->resume_dialog = dialog;
-
-	ephy_gui_window_update_user_time (session->priv->resume_dialog,
-					  user_time);
-
-	gtk_window_set_auto_startup_notification (FALSE);
-	response = gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_window_set_auto_startup_notification (TRUE);
-
-	gtk_widget_destroy (dialog);
-
-	session->priv->resume_dialog = NULL;
-
-	return (response == GTK_RESPONSE_ACCEPT);
-}
-
-/**
- * ephy_session_autoresume:
- * @session: a #EphySession
- * @user_time: a timestamp, or 0
- *
- * Resume a crashed session when necessary (interactive)
- *
- * Return value: TRUE if handled; windows have actually
- * been opened or the dialog from a previous instance
- * has been re-presented to the user.
- **/
-gboolean
-ephy_session_autoresume (EphySession *session,
-			 guint32 user_time)
-{
-	EphySessionPrivate *priv = session->priv;
-	char *saved_session;
-	gboolean retval = FALSE;
-
-	LOG ("ephy_session_autoresume");
-
-	if (priv->windows != NULL || priv->tool_windows != NULL) return FALSE;
-
-	if (priv->resume_dialog)
-	{
-		ephy_gui_window_update_user_time (priv->resume_dialog,
-						  user_time);
-		ephy_gui_window_present (GTK_WINDOW (priv->resume_dialog),
-					 user_time);
-		return TRUE;
-	}
-
-	saved_session = get_session_filename (SESSION_CRASHED);
-
-	if (g_file_test (saved_session, G_FILE_TEST_EXISTS)
-	    && offer_to_resume (session, user_time))
-	{
-		priv->dont_save = TRUE;
-		retval = ephy_session_load (session, saved_session,
-					    0 /* since we've shown the dialogue */);
-		priv->dont_save = FALSE;
-		ephy_session_save (session, SESSION_CRASHED);
-	}
-
-	g_free (saved_session);
-
-	/* ensure we don't open a blank window when quitting while resuming */
-	return retval || priv->quit_while_resuming;
-}
+/* Implementation */
 
 static void
 close_dialog (GtkWidget *widget)
@@ -480,12 +1011,15 @@ ephy_session_close (EphySession *session)
 	/* we have to ref the shell or else we may get finalised between
 	 * destroying the windows and destroying the tool windows
 	 */
-	g_object_ref (ephy_shell);
+	g_object_ref (ephy_shell_get_default ());
 
 	priv->dont_save = TRUE;
 	/* need to set this up here while the dialogue hasn't been killed yet */
 	priv->quit_while_resuming = priv->resume_dialog != NULL;	
 
+	/* Clear command queue */
+	session_command_queue_clear (session);
+
 	ephy_embed_shell_prepare_close (embed_shell);
 
 	/* there may still be windows open, like dialogues posed from
@@ -513,7 +1047,11 @@ ephy_session_close (EphySession *session)
 	g_list_free (windows);
 
 	session->priv->dont_save = FALSE;
-	g_object_unref (ephy_shell);
+
+	/* Clear command queue */
+	session_command_queue_clear (session);
+
+	g_object_unref (ephy_shell_get_default ());
 }
 
 static int
@@ -861,7 +1399,7 @@ restore_geometry (GtkWindow *window,
  * ephy_session_load:
  * @session: a #EphySession
  * @filename: the path of the source file
- * @user_time: a timestamp, or 0
+ * @user_time: a user_time, or 0
  *
  * Load a session from disk, restoring the windows and their state
  *
@@ -872,6 +1410,7 @@ ephy_session_load (EphySession *session,
 		   const char *filename,
 		   guint32 user_time)
 {
+	EphySessionPrivate *priv = session->priv;
 	xmlDocPtr doc;
         xmlNodePtr child;
 	EphyWindow *window;
@@ -890,6 +1429,10 @@ ephy_session_load (EphySession *session,
 		return FALSE;
 	}
 
+	g_object_ref (ephy_shell_get_default ());
+
+	priv->dont_save = TRUE;
+
 	child = xmlDocGetRootElement (doc);
 
 	/* skip the session node */
@@ -946,7 +1489,13 @@ ephy_session_load (EphySession *session,
 
 	xmlFreeDoc (doc);
 
-	return (session->priv->windows != NULL || session->priv->tool_windows != NULL);
+	priv->dont_save = FALSE;
+
+	ephy_session_save (session, SESSION_CRASHED);
+
+	g_object_unref (ephy_shell_get_default ());
+
+	return (priv->windows != NULL || priv->tool_windows != NULL);
 }
 
 /**
@@ -1034,3 +1583,78 @@ ephy_session_get_active_window (EphySession *session)
 
 	return window;
 }
+
+/**
+ * ephy_session_queue_command:
+ * @session: a #EphySession
+ **/
+void
+ephy_session_queue_command (EphySession *session,
+			    EphySessionCommand command,
+			    const char *arg,
+			    char **args,
+			    guint32 user_time,
+			    gboolean priority)
+{
+	EphySessionPrivate *priv;
+	GList *element;
+	SessionCommand *cmd;
+
+	LOG ("queue_command command:%d", command);
+
+	g_return_if_fail (EPHY_IS_SESSION (session));
+	g_return_if_fail (command != EPHY_SESSION_CMD_OPEN_URIS || args != NULL);
+
+	priv = session->priv;
+
+	/* First look if the same command is already queued */
+	if (command > EPHY_SESSION_CMD_RESUME_SESSION &&
+	    command < EPHY_SESSION_CMD_OPEN_URIS)
+	{
+		element = g_queue_find_custom (priv->queue,
+					       GINT_TO_POINTER (command),
+					       (GCompareFunc) session_command_find);
+		if (element != NULL)
+		{
+			cmd = (SessionCommand *) element->data;
+
+			if ((command == EPHY_SESSION_CMD_LOAD_SESSION &&
+			     strcmp (cmd->arg, arg) == 0) ||
+			    command == EPHY_SESSION_CMD_OPEN_BOOKMARKS_EDITOR ||
+			    command == EPHY_SESSION_CMD_RESUME_SESSION)
+			{
+				cmd->user_time = user_time;
+				g_queue_remove (priv->queue, cmd);
+				g_queue_push_tail (priv->queue, cmd);
+
+				return;
+			}
+		}
+	}
+
+	/* FIXME: use g_slice_new */
+	cmd = g_new0 (SessionCommand, 1);
+	cmd->command = command;
+	cmd->arg = arg ? g_strdup (arg) : NULL;
+	cmd->args = args ? g_strdupv (args) : NULL;
+	cmd->user_time = user_time;
+	/* This ref is released in session_command_free */
+	g_object_ref (ephy_shell_get_default ());
+
+	if (priority)
+	{
+		g_queue_push_head (priv->queue, cmd);
+	}
+	else
+	{
+		g_queue_push_tail (priv->queue, cmd);
+	}
+
+	session_command_queue_next (session);
+
+	if (priv->resume_dialog != NULL)
+	{
+		gtk_window_present_with_time (GTK_WINDOW (priv->resume_dialog),
+					      user_time);
+	}
+}
