@@ -1,6 +1,6 @@
 /* 
- *  Copyright (C) 2000-2004 Marco Pesenti Gritti
- *  Copyright (C) 2003-2005 Christian Persch
+ *  Copyright © 2000-2004 Marco Pesenti Gritti
+ *  Copyright © 2003-2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbar-editor.c,v 1.8 2006/08/07 20:13:15 chpe Exp $
+ *  $Id: ephy-toolbar-editor.c 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "config.h"
@@ -378,7 +378,7 @@ ephy_toolbar_editor_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyToolbarEditorClass),
 			NULL,
